#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 z-pandoc-z-xml-light
version:              3.6
package-name:         pandoc
lib-name:             xml-light
id:                   pandoc-3.6-BRBrLfgnBfe2zs6oO7vWhF-xml-light
key:                  pandoc-3.6-BRBrLfgnBfe2zs6oO7vWhF-xml-light
license:              GPL-2.0-or-later
copyright:            (c) 2006-2024 John MacFarlane
maintainer:           John MacFarlane <jgm@berkeley.edu>
author:               John MacFarlane <jgm@berkeley.edu>
stability:            alpha
homepage:             https://pandoc.org
synopsis:             Conversion between markup formats
description:
    Pandoc is a Haskell library for converting from one markup
    format to another.  The formats it can handle include

    - light markup formats (many variants of Markdown,
    reStructuredText, AsciiDoc, Org-mode, Muse, Textile,
    txt2tags, djot)
    - HTML formats (HTML 4 and 5)
    - Ebook formats (EPUB v2 and v3, FB2)
    - Documentation formats (GNU TexInfo, Haddock)
    - Roff formats (man, ms)
    - TeX formats (LaTeX, ConTeXt)
    - Typst
    - XML formats (DocBook 4 and 5, JATS, TEI Simple, OpenDocument)
    - Outline formats (OPML)
    - Bibliography formats (BibTeX, BibLaTeX, CSL JSON, CSL YAML,
    RIS)
    - Word processor formats (Docx, RTF, ODT)
    - Interactive notebook formats (Jupyter notebook ipynb)
    - Page layout formats (InDesign ICML)
    - Wiki markup formats (MediaWiki, DokuWiki, TikiWiki, TWiki,
    Vimwiki, XWiki, ZimWiki, Jira wiki, Creole)
    - Slide show formats (LaTeX Beamer, PowerPoint, Slidy,
    reveal.js, Slideous, S5, DZSlides)
    - Data formats (CSV and TSV tables)
    - PDF (via external programs such as pdflatex or wkhtmltopdf)

    Pandoc can convert mathematical content in documents
    between TeX, MathML, Word equations, roff eqn, typst,
    and plain text. It includes a powerful system for automatic
    citations and bibliographies, and it can be customized
    extensively using templates, filters, and custom readers
    and writers written in Lua.

    For the pandoc command-line program, see the
    @pandoc-cli@ package.

category:             Text
abi:                  cb3fd645def988696551782a60f34c62
exposed-modules:
    Text.Pandoc.XML.Light Text.Pandoc.XML.Light.Output
    Text.Pandoc.XML.Light.Proc Text.Pandoc.XML.Light.Types

import-dirs:          /usr/lib/ghc-9.6.6/site-local/pandoc-3.6
library-dirs:         /usr/lib/ghc-9.6.6/site-local/pandoc-3.6
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/pandoc-3.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pandoc
hs-libraries:         HSpandoc-3.6-BRBrLfgnBfe2zs6oO7vWhF-xml-light
depends:
    base-4.18.2.1 containers-0.6.7 text-2.0.2
    xml-1.3.14-3CsuYrgQlhu1X5fBOwcswt
    xml-conduit-1.9.1.4-HR85KtUhDop5fDlLuGNMPr
    xml-types-0.3.8-ISf6rjkeTjSFXsXdIGBwau

haddock-interfaces:   /usr/share/doc/haskell-pandoc/html/pandoc.haddock
haddock-html:         /usr/share/doc/haskell-pandoc/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 pandoc
version:              3.6
visibility:           public
id:                   pandoc-3.6-AEm91vKxfQ9D3hkyZsENl3
key:                  pandoc-3.6-AEm91vKxfQ9D3hkyZsENl3
license:              GPL-2.0-or-later
copyright:            (c) 2006-2024 John MacFarlane
maintainer:           John MacFarlane <jgm@berkeley.edu>
author:               John MacFarlane <jgm@berkeley.edu>
stability:            alpha
homepage:             https://pandoc.org
synopsis:             Conversion between markup formats
description:
    Pandoc is a Haskell library for converting from one markup
    format to another.  The formats it can handle include

    - light markup formats (many variants of Markdown,
    reStructuredText, AsciiDoc, Org-mode, Muse, Textile,
    txt2tags, djot)
    - HTML formats (HTML 4 and 5)
    - Ebook formats (EPUB v2 and v3, FB2)
    - Documentation formats (GNU TexInfo, Haddock)
    - Roff formats (man, ms)
    - TeX formats (LaTeX, ConTeXt)
    - Typst
    - XML formats (DocBook 4 and 5, JATS, TEI Simple, OpenDocument)
    - Outline formats (OPML)
    - Bibliography formats (BibTeX, BibLaTeX, CSL JSON, CSL YAML,
    RIS)
    - Word processor formats (Docx, RTF, ODT)
    - Interactive notebook formats (Jupyter notebook ipynb)
    - Page layout formats (InDesign ICML)
    - Wiki markup formats (MediaWiki, DokuWiki, TikiWiki, TWiki,
    Vimwiki, XWiki, ZimWiki, Jira wiki, Creole)
    - Slide show formats (LaTeX Beamer, PowerPoint, Slidy,
    reveal.js, Slideous, S5, DZSlides)
    - Data formats (CSV and TSV tables)
    - PDF (via external programs such as pdflatex or wkhtmltopdf)

    Pandoc can convert mathematical content in documents
    between TeX, MathML, Word equations, roff eqn, typst,
    and plain text. It includes a powerful system for automatic
    citations and bibliographies, and it can be customized
    extensively using templates, filters, and custom readers
    and writers written in Lua.

    For the pandoc command-line program, see the
    @pandoc-cli@ package.

category:             Text
abi:                  d5ef79dad2d4c207cf7d05e90001848a
exposed:              True
exposed-modules:
    Text.Pandoc Text.Pandoc.App Text.Pandoc.Asciify Text.Pandoc.Chunks
    Text.Pandoc.Citeproc Text.Pandoc.Class Text.Pandoc.Class.IO
    Text.Pandoc.Data Text.Pandoc.Emoji Text.Pandoc.Error
    Text.Pandoc.Extensions Text.Pandoc.Filter Text.Pandoc.Format
    Text.Pandoc.Highlighting Text.Pandoc.ImageSize Text.Pandoc.Logging
    Text.Pandoc.MIME Text.Pandoc.MediaBag Text.Pandoc.Options
    Text.Pandoc.PDF Text.Pandoc.Parsing Text.Pandoc.Process
    Text.Pandoc.Readers Text.Pandoc.Readers.BibTeX
    Text.Pandoc.Readers.CSV Text.Pandoc.Readers.CommonMark
    Text.Pandoc.Readers.Creole Text.Pandoc.Readers.CslJson
    Text.Pandoc.Readers.Djot Text.Pandoc.Readers.DocBook
    Text.Pandoc.Readers.Docx Text.Pandoc.Readers.DokuWiki
    Text.Pandoc.Readers.EPUB Text.Pandoc.Readers.EndNote
    Text.Pandoc.Readers.FB2 Text.Pandoc.Readers.HTML
    Text.Pandoc.Readers.Haddock Text.Pandoc.Readers.Ipynb
    Text.Pandoc.Readers.JATS Text.Pandoc.Readers.Jira
    Text.Pandoc.Readers.LaTeX Text.Pandoc.Readers.Man
    Text.Pandoc.Readers.Markdown Text.Pandoc.Readers.Mdoc
    Text.Pandoc.Readers.MediaWiki Text.Pandoc.Readers.Muse
    Text.Pandoc.Readers.Native Text.Pandoc.Readers.ODT
    Text.Pandoc.Readers.OPML Text.Pandoc.Readers.Org
    Text.Pandoc.Readers.RIS Text.Pandoc.Readers.RST
    Text.Pandoc.Readers.RTF Text.Pandoc.Readers.TWiki
    Text.Pandoc.Readers.Textile Text.Pandoc.Readers.TikiWiki
    Text.Pandoc.Readers.Txt2Tags Text.Pandoc.Readers.Typst
    Text.Pandoc.Readers.Vimwiki Text.Pandoc.Scripting
    Text.Pandoc.SelfContained Text.Pandoc.Shared Text.Pandoc.Slides
    Text.Pandoc.Sources Text.Pandoc.Templates Text.Pandoc.Transforms
    Text.Pandoc.Translations Text.Pandoc.Translations.Types
    Text.Pandoc.UTF8 Text.Pandoc.Version Text.Pandoc.Writers
    Text.Pandoc.Writers.ANSI Text.Pandoc.Writers.AnnotatedTable
    Text.Pandoc.Writers.AsciiDoc Text.Pandoc.Writers.BibTeX
    Text.Pandoc.Writers.ChunkedHTML Text.Pandoc.Writers.CommonMark
    Text.Pandoc.Writers.ConTeXt Text.Pandoc.Writers.CslJson
    Text.Pandoc.Writers.Djot Text.Pandoc.Writers.DocBook
    Text.Pandoc.Writers.Docx Text.Pandoc.Writers.DokuWiki
    Text.Pandoc.Writers.EPUB Text.Pandoc.Writers.FB2
    Text.Pandoc.Writers.HTML Text.Pandoc.Writers.Haddock
    Text.Pandoc.Writers.ICML Text.Pandoc.Writers.Ipynb
    Text.Pandoc.Writers.JATS Text.Pandoc.Writers.Jira
    Text.Pandoc.Writers.LaTeX Text.Pandoc.Writers.Man
    Text.Pandoc.Writers.Markdown Text.Pandoc.Writers.Math
    Text.Pandoc.Writers.MediaWiki Text.Pandoc.Writers.Ms
    Text.Pandoc.Writers.Muse Text.Pandoc.Writers.Native
    Text.Pandoc.Writers.ODT Text.Pandoc.Writers.OOXML
    Text.Pandoc.Writers.OPML Text.Pandoc.Writers.OpenDocument
    Text.Pandoc.Writers.Org Text.Pandoc.Writers.Powerpoint
    Text.Pandoc.Writers.RST Text.Pandoc.Writers.RTF
    Text.Pandoc.Writers.Shared Text.Pandoc.Writers.TEI
    Text.Pandoc.Writers.Texinfo Text.Pandoc.Writers.Textile
    Text.Pandoc.Writers.Typst Text.Pandoc.Writers.XWiki
    Text.Pandoc.Writers.ZimWiki Text.Pandoc.XML

hidden-modules:
    Text.Pandoc.App.CommandLineOptions Text.Pandoc.App.Input
    Text.Pandoc.App.Opt Text.Pandoc.App.OutputSettings
    Text.Pandoc.Class.CommonState Text.Pandoc.Class.PandocMonad
    Text.Pandoc.Class.PandocIO Text.Pandoc.Class.PandocPure
    Text.Pandoc.Class.Sandbox Text.Pandoc.Filter.Environment
    Text.Pandoc.Filter.JSON Text.Pandoc.Parsing.Capabilities
    Text.Pandoc.Parsing.Citations Text.Pandoc.Parsing.General
    Text.Pandoc.Parsing.GridTable Text.Pandoc.Parsing.Lists
    Text.Pandoc.Parsing.Math Text.Pandoc.Parsing.Smart
    Text.Pandoc.Parsing.State Text.Pandoc.Parsing.Future
    Text.Pandoc.Readers.Docx.Lists Text.Pandoc.Readers.Docx.Combine
    Text.Pandoc.Readers.Docx.Parse
    Text.Pandoc.Readers.Docx.Parse.Styles Text.Pandoc.Readers.Docx.Util
    Text.Pandoc.Readers.Docx.Symbols Text.Pandoc.Readers.Docx.Fields
    Text.Pandoc.Readers.HTML.Parsing Text.Pandoc.Readers.HTML.Table
    Text.Pandoc.Readers.HTML.TagCategories
    Text.Pandoc.Readers.HTML.Types Text.Pandoc.Readers.LaTeX.Inline
    Text.Pandoc.Readers.LaTeX.Citation Text.Pandoc.Readers.LaTeX.Lang
    Text.Pandoc.Readers.LaTeX.Macro Text.Pandoc.Readers.LaTeX.Math
    Text.Pandoc.Readers.LaTeX.Parsing Text.Pandoc.Readers.LaTeX.SIunitx
    Text.Pandoc.Readers.LaTeX.Table Text.Pandoc.Readers.Mdoc.Lex
    Text.Pandoc.Readers.Mdoc.Macros Text.Pandoc.Readers.Mdoc.Standards
    Text.Pandoc.Readers.Typst.Parsing Text.Pandoc.Readers.Typst.Math
    Text.Pandoc.Readers.ODT.Base Text.Pandoc.Readers.ODT.Namespaces
    Text.Pandoc.Readers.ODT.StyleReader
    Text.Pandoc.Readers.ODT.ContentReader
    Text.Pandoc.Readers.ODT.Generic.Fallible
    Text.Pandoc.Readers.ODT.Generic.SetMap
    Text.Pandoc.Readers.ODT.Generic.Utils
    Text.Pandoc.Readers.ODT.Generic.Namespaces
    Text.Pandoc.Readers.ODT.Generic.XMLConverter
    Text.Pandoc.Readers.ODT.Arrows.State
    Text.Pandoc.Readers.ODT.Arrows.Utils
    Text.Pandoc.Readers.Org.BlockStarts Text.Pandoc.Readers.Org.Blocks
    Text.Pandoc.Readers.Org.DocumentTree
    Text.Pandoc.Readers.Org.ExportSettings
    Text.Pandoc.Readers.Org.Inlines Text.Pandoc.Readers.Org.Meta
    Text.Pandoc.Readers.Org.ParserState Text.Pandoc.Readers.Org.Parsing
    Text.Pandoc.Readers.Org.Shared Text.Pandoc.Readers.Metadata
    Text.Pandoc.Readers.Roff Text.Pandoc.Readers.Roff.Escape
    Text.Pandoc.Writers.Docx.OpenXML Text.Pandoc.Writers.Docx.StyleMap
    Text.Pandoc.Writers.Docx.Table Text.Pandoc.Writers.Docx.Types
    Text.Pandoc.Writers.GridTable Text.Pandoc.Writers.JATS.References
    Text.Pandoc.Writers.JATS.Table Text.Pandoc.Writers.JATS.Types
    Text.Pandoc.Writers.LaTeX.Caption Text.Pandoc.Writers.LaTeX.Notes
    Text.Pandoc.Writers.LaTeX.Table Text.Pandoc.Writers.LaTeX.Lang
    Text.Pandoc.Writers.LaTeX.Types Text.Pandoc.Writers.LaTeX.Citation
    Text.Pandoc.Writers.LaTeX.Util Text.Pandoc.Writers.Markdown.Table
    Text.Pandoc.Writers.Markdown.Types
    Text.Pandoc.Writers.Markdown.Inline Text.Pandoc.Writers.Roff
    Text.Pandoc.Writers.Blaze
    Text.Pandoc.Writers.Powerpoint.Presentation
    Text.Pandoc.Writers.Powerpoint.Output Text.Pandoc.Char
    Text.Pandoc.TeX Text.Pandoc.URI Text.Pandoc.CSS Text.Pandoc.CSV
    Text.Pandoc.RoffChar Text.Pandoc.UUID Text.Pandoc.Image
    Text.Pandoc.Citeproc.BibTeX Text.Pandoc.Citeproc.Name
    Text.Pandoc.Citeproc.CslJson Text.Pandoc.Citeproc.Data
    Text.Pandoc.Citeproc.Locator Text.Pandoc.Citeproc.MetaValue
    Text.Pandoc.Citeproc.Util Paths_pandoc

import-dirs:          /usr/lib/ghc-9.6.6/site-local/pandoc-3.6
library-dirs:         /usr/lib/ghc-9.6.6/site-local/pandoc-3.6
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/pandoc-3.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pandoc
hs-libraries:         HSpandoc-3.6-AEm91vKxfQ9D3hkyZsENl3
depends:
    Glob-0.10.2-8s0wbnBYMNO3GH6wkOA3t6
    JuicyPixels-3.3.9-5EsNAc2nq7A1nxLrSmqxjg
    aeson-2.2.2.0-C59vZnSjH3DEmVbOnYEZqj
    aeson-pretty-0.8.11-BF5xTcMyKkiDM3IwcPJ1Vo array-0.5.6.0
    attoparsec-0.14.4-Jn9OdnAKkVz1hO2dwh0zwz base-4.18.2.1
    base64-bytestring-1.2.1.0-LZzfJtlIG52AkUlWG0qoMe binary-0.8.9.1
    blaze-html-0.9.2.0-GzsXlvfrcqyCxImJscSKAz
    blaze-markup-0.8.3.0-BOWeQpAnxz8Cf8hQ9GVt6j bytestring-0.11.5.3
    case-insensitive-1.2.1.0-2Yyf9IxnGFQLPP0jk4pg3Q
    citeproc-0.8.1.2-5H7qb89hyB6JlDLjKVf823
    commonmark-0.2.6.1-1VUfvRyzXQrHiSgx8vlahO
    commonmark-extensions-0.2.5.6-BnCMBLE6TyPCAZ3LwqhdCc
    commonmark-pandoc-0.2.3-CE7MPJcnasP9M9eM9q69Y7 containers-0.6.7
    crypton-1.0.4-5dxKfIBRa6R2YE55iyrOUy
    crypton-connection-0.4.5-8C7ImH1gIrB4Th9ehqNZaa
    crypton-x509-system-1.6.8-Ce1ogCTDbL1ARFsPtWH5XM
    data-default-0.7.1.3-v65wBq6p7UHdeTWfWwzRF deepseq-1.4.8.1
    directory-1.3.8.5 djot-0.1.2.4-8oSIjdabG0IDutK3tUATq6
    doclayout-0.5.0.1-CEcghpycHQhEpL5xYe1f1L
    doctemplates-0.11.0.1-4BXMMGvwEDP1o5BMPJLJ9z
    emojis-0.1.5-BbLPu733TaPFnd8yi2bC1O exceptions-0.10.7
    file-embed-0.0.16.0-6A32wX7iXBC7ZTuLWlLLWz filepath-1.4.300.1
    gridtables-0.1.1.0-4B3xnfXbtW35nrBiy5vC5
    haddock-library-1.11.0-81YK0ELPXnW5bhLL1SLTYB
    http-client-0.7.19-LN5QT3bQF9y5GsNu19wbhO
    http-client-tls-0.3.6.4-BpM0XRSvwZ99JZv1J5vtXV
    http-types-0.12.4-57DQrkzau5HINFiGCpRQOB
    ipynb-0.2-7njINTmUwngJ8qJjyp3K75
    jira-wiki-markup-1.5.1-5LG6pZD7WxqCkVBVUCaSVG
    libyaml-0.1.4-8qzdVh2NPgkIzom9F9KR6q
    mime-types-0.1.2.1-1xtxegTvlKyFu1aTXaUpBN mtl-2.3.1
    network-3.1.4.0-FBuTdTHZ29uBPcO3Y238RO
    network-uri-2.6.4.2-Fs1V3yFgC4iGyoDpGJIE7J
    pandoc-3.6-BRBrLfgnBfe2zs6oO7vWhF-xml-light
    pandoc-types-1.23.1.1-2le9qh5vQuCLiqT4gx4lIM parsec-3.1.16.1
    pretty-1.1.3.6 pretty-show-1.10-EXsS4VwIV5tJ56gbmVdfrR
    process-1.6.19.0 random-1.2.1.3-2D6Xw54bvJBUzxlFqHjEz
    safe-0.3.21-9gbMGq7NJ675hqTemGOkyG
    scientific-0.3.8.1-AT3R4FMwAbnHAVDYpRwOmQ
    skylighting-0.14.5-G8KGNDOmouu983nOLub22F
    skylighting-core-0.14.5-Jbtw2frZqYf4GvbGMhcn65
    split-0.2.5-3KQHz3VjCt4O3lCLzOFzl syb-0.7.3-11K0viXu9hkJBGIPMEQMvn
    tagsoup-0.14.8-F4Ry8R73HlTBvOvfzZMJjd
    temporary-1.3-BCLEeiJZS9p2VFxBOmtDaG
    texmath-0.12.8.12-EN1xBroYxDb4Pif6GzHRfk text-2.0.2
    text-conversions-0.3.1.1-GwenEGuPmsT2YuTBkypbmg time-1.12.2
    tls-2.0.6-GRwo7CG1RJd8Igyy5Lhrq1 typst-0.6.1-BFfuGktQns9IErM418dPrP
    unicode-collation-0.1.3.7-3FJ2Dl26dl7BOx6NGRxBf4
    unicode-transforms-0.4.0.1-4no9zDVyLqxESgtwsdKbxY unix-2.8.4.0
    vector-0.13.2.0-HJSwbt845rQ2AOZrNm5BDk
    xml-1.3.14-3CsuYrgQlhu1X5fBOwcswt
    yaml-0.11.11.2-7UoXYkKWr4r4oNCJDlnyxG
    zip-archive-0.4.3.2-GF01YJ4Y7mT94q7blBMXAe
    zlib-0.7.1.0-C72dPpIBAem76SHRIfq7NC

haddock-interfaces:   /usr/share/doc/haskell-pandoc/html/pandoc.haddock
haddock-html:         /usr/share/doc/haskell-pandoc/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

